# slurmrestpy
API to access and control Slurm

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: Slurm-24.11.1&amp;openapi/slurmdbd&amp;openapi/slurmctld
- Package version: 1.0.0
- Generator version: 7.12.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.schedmd.com/](https://www.schedmd.com/)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

`slurmrestpy` is available on PyPi, so you can install with

```sh
pip install slurmrestpy
```

If you would prefer to install from this repo, you can install directly using:

```sh
pip install git+https://github.com/AndyStevens/slurmrestpy.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import slurmrestpy
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import slurmrestpy
from slurmrestpy.models.v0040_openapi_diag_resp import V0040OpenapiDiagResp
from slurmrestpy.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost, please put in the URL of your Slurm instance
# See configuration.py for a list of all supported configuration parameters.
configuration = slurmrestpy.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: user
# configuration.api_key['user'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['user'] = 'Bearer'

# Configure Bearer authorization (JWT): bearerAuth
configuration = slurmrestpy.Configuration(
    access_token = access_token
)

# Configure API key authorization: token
# configuration.api_key['token'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['token'] = 'Bearer'

# Enter a context with an instance of the API client
with slurmrestpy.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = slurmrestpy.SlurmApi(api_client)

    try:
        # get diagnostics
        api_response = api_instance.slurm_v0040_get_diag()
        print("The response of SlurmApi->slurm_v0040_get_diag:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling SlurmApi->slurm_v0040_get_diag: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SlurmApi* | [**slurm_v0040_delete_job**](docs/SlurmApi.md#slurm_v0040_delete_job) | **DELETE** /slurm/v0.0.40/job/{job_id} | cancel or signal job
*SlurmApi* | [**slurm_v0040_delete_jobs**](docs/SlurmApi.md#slurm_v0040_delete_jobs) | **DELETE** /slurm/v0.0.40/jobs/ | send signal to list of jobs
*SlurmApi* | [**slurm_v0040_delete_node**](docs/SlurmApi.md#slurm_v0040_delete_node) | **DELETE** /slurm/v0.0.40/node/{node_name} | delete node
*SlurmApi* | [**slurm_v0040_get_diag**](docs/SlurmApi.md#slurm_v0040_get_diag) | **GET** /slurm/v0.0.40/diag/ | get diagnostics
*SlurmApi* | [**slurm_v0040_get_job**](docs/SlurmApi.md#slurm_v0040_get_job) | **GET** /slurm/v0.0.40/job/{job_id} | get job info
*SlurmApi* | [**slurm_v0040_get_jobs**](docs/SlurmApi.md#slurm_v0040_get_jobs) | **GET** /slurm/v0.0.40/jobs/ | get list of jobs
*SlurmApi* | [**slurm_v0040_get_jobs_state**](docs/SlurmApi.md#slurm_v0040_get_jobs_state) | **GET** /slurm/v0.0.40/jobs/state/ | get list of job states
*SlurmApi* | [**slurm_v0040_get_licenses**](docs/SlurmApi.md#slurm_v0040_get_licenses) | **GET** /slurm/v0.0.40/licenses/ | get all Slurm tracked license info
*SlurmApi* | [**slurm_v0040_get_node**](docs/SlurmApi.md#slurm_v0040_get_node) | **GET** /slurm/v0.0.40/node/{node_name} | get node info
*SlurmApi* | [**slurm_v0040_get_nodes**](docs/SlurmApi.md#slurm_v0040_get_nodes) | **GET** /slurm/v0.0.40/nodes/ | get node(s) info
*SlurmApi* | [**slurm_v0040_get_partition**](docs/SlurmApi.md#slurm_v0040_get_partition) | **GET** /slurm/v0.0.40/partition/{partition_name} | get partition info
*SlurmApi* | [**slurm_v0040_get_partitions**](docs/SlurmApi.md#slurm_v0040_get_partitions) | **GET** /slurm/v0.0.40/partitions/ | get all partition info
*SlurmApi* | [**slurm_v0040_get_ping**](docs/SlurmApi.md#slurm_v0040_get_ping) | **GET** /slurm/v0.0.40/ping/ | ping test
*SlurmApi* | [**slurm_v0040_get_reconfigure**](docs/SlurmApi.md#slurm_v0040_get_reconfigure) | **GET** /slurm/v0.0.40/reconfigure/ | request slurmctld reconfigure
*SlurmApi* | [**slurm_v0040_get_reservation**](docs/SlurmApi.md#slurm_v0040_get_reservation) | **GET** /slurm/v0.0.40/reservation/{reservation_name} | get reservation info
*SlurmApi* | [**slurm_v0040_get_reservations**](docs/SlurmApi.md#slurm_v0040_get_reservations) | **GET** /slurm/v0.0.40/reservations/ | get all reservation info
*SlurmApi* | [**slurm_v0040_get_shares**](docs/SlurmApi.md#slurm_v0040_get_shares) | **GET** /slurm/v0.0.40/shares | get fairshare info
*SlurmApi* | [**slurm_v0040_post_job**](docs/SlurmApi.md#slurm_v0040_post_job) | **POST** /slurm/v0.0.40/job/{job_id} | update job
*SlurmApi* | [**slurm_v0040_post_job_submit**](docs/SlurmApi.md#slurm_v0040_post_job_submit) | **POST** /slurm/v0.0.40/job/submit | submit new job
*SlurmApi* | [**slurm_v0040_post_node**](docs/SlurmApi.md#slurm_v0040_post_node) | **POST** /slurm/v0.0.40/node/{node_name} | update node properties
*SlurmApi* | [**slurm_v0040_post_nodes**](docs/SlurmApi.md#slurm_v0040_post_nodes) | **POST** /slurm/v0.0.40/nodes/ | batch update node(s)
*SlurmApi* | [**slurm_v0041_delete_job**](docs/SlurmApi.md#slurm_v0041_delete_job) | **DELETE** /slurm/v0.0.41/job/{job_id} | cancel or signal job
*SlurmApi* | [**slurm_v0041_delete_jobs**](docs/SlurmApi.md#slurm_v0041_delete_jobs) | **DELETE** /slurm/v0.0.41/jobs/ | send signal to list of jobs
*SlurmApi* | [**slurm_v0041_delete_node**](docs/SlurmApi.md#slurm_v0041_delete_node) | **DELETE** /slurm/v0.0.41/node/{node_name} | delete node
*SlurmApi* | [**slurm_v0041_get_diag**](docs/SlurmApi.md#slurm_v0041_get_diag) | **GET** /slurm/v0.0.41/diag/ | get diagnostics
*SlurmApi* | [**slurm_v0041_get_job**](docs/SlurmApi.md#slurm_v0041_get_job) | **GET** /slurm/v0.0.41/job/{job_id} | get job info
*SlurmApi* | [**slurm_v0041_get_jobs**](docs/SlurmApi.md#slurm_v0041_get_jobs) | **GET** /slurm/v0.0.41/jobs/ | get list of jobs
*SlurmApi* | [**slurm_v0041_get_jobs_state**](docs/SlurmApi.md#slurm_v0041_get_jobs_state) | **GET** /slurm/v0.0.41/jobs/state/ | get list of job states
*SlurmApi* | [**slurm_v0041_get_licenses**](docs/SlurmApi.md#slurm_v0041_get_licenses) | **GET** /slurm/v0.0.41/licenses/ | get all Slurm tracked license info
*SlurmApi* | [**slurm_v0041_get_node**](docs/SlurmApi.md#slurm_v0041_get_node) | **GET** /slurm/v0.0.41/node/{node_name} | get node info
*SlurmApi* | [**slurm_v0041_get_nodes**](docs/SlurmApi.md#slurm_v0041_get_nodes) | **GET** /slurm/v0.0.41/nodes/ | get node(s) info
*SlurmApi* | [**slurm_v0041_get_partition**](docs/SlurmApi.md#slurm_v0041_get_partition) | **GET** /slurm/v0.0.41/partition/{partition_name} | get partition info
*SlurmApi* | [**slurm_v0041_get_partitions**](docs/SlurmApi.md#slurm_v0041_get_partitions) | **GET** /slurm/v0.0.41/partitions/ | get all partition info
*SlurmApi* | [**slurm_v0041_get_ping**](docs/SlurmApi.md#slurm_v0041_get_ping) | **GET** /slurm/v0.0.41/ping/ | ping test
*SlurmApi* | [**slurm_v0041_get_reconfigure**](docs/SlurmApi.md#slurm_v0041_get_reconfigure) | **GET** /slurm/v0.0.41/reconfigure/ | request slurmctld reconfigure
*SlurmApi* | [**slurm_v0041_get_reservation**](docs/SlurmApi.md#slurm_v0041_get_reservation) | **GET** /slurm/v0.0.41/reservation/{reservation_name} | get reservation info
*SlurmApi* | [**slurm_v0041_get_reservations**](docs/SlurmApi.md#slurm_v0041_get_reservations) | **GET** /slurm/v0.0.41/reservations/ | get all reservation info
*SlurmApi* | [**slurm_v0041_get_shares**](docs/SlurmApi.md#slurm_v0041_get_shares) | **GET** /slurm/v0.0.41/shares | get fairshare info
*SlurmApi* | [**slurm_v0041_post_job**](docs/SlurmApi.md#slurm_v0041_post_job) | **POST** /slurm/v0.0.41/job/{job_id} | update job
*SlurmApi* | [**slurm_v0041_post_job_allocate**](docs/SlurmApi.md#slurm_v0041_post_job_allocate) | **POST** /slurm/v0.0.41/job/allocate | submit new job allocation without any steps that must be signaled to stop
*SlurmApi* | [**slurm_v0041_post_job_submit**](docs/SlurmApi.md#slurm_v0041_post_job_submit) | **POST** /slurm/v0.0.41/job/submit | submit new job
*SlurmApi* | [**slurm_v0041_post_node**](docs/SlurmApi.md#slurm_v0041_post_node) | **POST** /slurm/v0.0.41/node/{node_name} | update node properties
*SlurmApi* | [**slurm_v0041_post_nodes**](docs/SlurmApi.md#slurm_v0041_post_nodes) | **POST** /slurm/v0.0.41/nodes/ | batch update node(s)
*SlurmApi* | [**slurm_v0042_delete_job**](docs/SlurmApi.md#slurm_v0042_delete_job) | **DELETE** /slurm/v0.0.42/job/{job_id} | cancel or signal job
*SlurmApi* | [**slurm_v0042_delete_jobs**](docs/SlurmApi.md#slurm_v0042_delete_jobs) | **DELETE** /slurm/v0.0.42/jobs/ | send signal to list of jobs
*SlurmApi* | [**slurm_v0042_delete_node**](docs/SlurmApi.md#slurm_v0042_delete_node) | **DELETE** /slurm/v0.0.42/node/{node_name} | delete node
*SlurmApi* | [**slurm_v0042_get_diag**](docs/SlurmApi.md#slurm_v0042_get_diag) | **GET** /slurm/v0.0.42/diag/ | get diagnostics
*SlurmApi* | [**slurm_v0042_get_job**](docs/SlurmApi.md#slurm_v0042_get_job) | **GET** /slurm/v0.0.42/job/{job_id} | get job info
*SlurmApi* | [**slurm_v0042_get_jobs**](docs/SlurmApi.md#slurm_v0042_get_jobs) | **GET** /slurm/v0.0.42/jobs/ | get list of jobs
*SlurmApi* | [**slurm_v0042_get_jobs_state**](docs/SlurmApi.md#slurm_v0042_get_jobs_state) | **GET** /slurm/v0.0.42/jobs/state/ | get list of job states
*SlurmApi* | [**slurm_v0042_get_licenses**](docs/SlurmApi.md#slurm_v0042_get_licenses) | **GET** /slurm/v0.0.42/licenses/ | get all Slurm tracked license info
*SlurmApi* | [**slurm_v0042_get_node**](docs/SlurmApi.md#slurm_v0042_get_node) | **GET** /slurm/v0.0.42/node/{node_name} | get node info
*SlurmApi* | [**slurm_v0042_get_nodes**](docs/SlurmApi.md#slurm_v0042_get_nodes) | **GET** /slurm/v0.0.42/nodes/ | get node(s) info
*SlurmApi* | [**slurm_v0042_get_partition**](docs/SlurmApi.md#slurm_v0042_get_partition) | **GET** /slurm/v0.0.42/partition/{partition_name} | get partition info
*SlurmApi* | [**slurm_v0042_get_partitions**](docs/SlurmApi.md#slurm_v0042_get_partitions) | **GET** /slurm/v0.0.42/partitions/ | get all partition info
*SlurmApi* | [**slurm_v0042_get_ping**](docs/SlurmApi.md#slurm_v0042_get_ping) | **GET** /slurm/v0.0.42/ping/ | ping test
*SlurmApi* | [**slurm_v0042_get_reconfigure**](docs/SlurmApi.md#slurm_v0042_get_reconfigure) | **GET** /slurm/v0.0.42/reconfigure/ | request slurmctld reconfigure
*SlurmApi* | [**slurm_v0042_get_reservation**](docs/SlurmApi.md#slurm_v0042_get_reservation) | **GET** /slurm/v0.0.42/reservation/{reservation_name} | get reservation info
*SlurmApi* | [**slurm_v0042_get_reservations**](docs/SlurmApi.md#slurm_v0042_get_reservations) | **GET** /slurm/v0.0.42/reservations/ | get all reservation info
*SlurmApi* | [**slurm_v0042_get_shares**](docs/SlurmApi.md#slurm_v0042_get_shares) | **GET** /slurm/v0.0.42/shares | get fairshare info
*SlurmApi* | [**slurm_v0042_post_job**](docs/SlurmApi.md#slurm_v0042_post_job) | **POST** /slurm/v0.0.42/job/{job_id} | update job
*SlurmApi* | [**slurm_v0042_post_job_allocate**](docs/SlurmApi.md#slurm_v0042_post_job_allocate) | **POST** /slurm/v0.0.42/job/allocate | submit new job allocation without any steps that must be signaled to stop
*SlurmApi* | [**slurm_v0042_post_job_submit**](docs/SlurmApi.md#slurm_v0042_post_job_submit) | **POST** /slurm/v0.0.42/job/submit | submit new job
*SlurmApi* | [**slurm_v0042_post_node**](docs/SlurmApi.md#slurm_v0042_post_node) | **POST** /slurm/v0.0.42/node/{node_name} | update node properties
*SlurmApi* | [**slurm_v0042_post_nodes**](docs/SlurmApi.md#slurm_v0042_post_nodes) | **POST** /slurm/v0.0.42/nodes/ | batch update node(s)
*SlurmdbApi* | [**slurmdb_v0040_delete_account**](docs/SlurmdbApi.md#slurmdb_v0040_delete_account) | **DELETE** /slurmdb/v0.0.40/account/{account_name} | Delete account
*SlurmdbApi* | [**slurmdb_v0040_delete_association**](docs/SlurmdbApi.md#slurmdb_v0040_delete_association) | **DELETE** /slurmdb/v0.0.40/association/ | Delete association
*SlurmdbApi* | [**slurmdb_v0040_delete_associations**](docs/SlurmdbApi.md#slurmdb_v0040_delete_associations) | **DELETE** /slurmdb/v0.0.40/associations/ | Delete associations
*SlurmdbApi* | [**slurmdb_v0040_delete_cluster**](docs/SlurmdbApi.md#slurmdb_v0040_delete_cluster) | **DELETE** /slurmdb/v0.0.40/cluster/{cluster_name} | Delete cluster
*SlurmdbApi* | [**slurmdb_v0040_delete_single_qos**](docs/SlurmdbApi.md#slurmdb_v0040_delete_single_qos) | **DELETE** /slurmdb/v0.0.40/qos/{qos} | Delete QOS
*SlurmdbApi* | [**slurmdb_v0040_delete_user**](docs/SlurmdbApi.md#slurmdb_v0040_delete_user) | **DELETE** /slurmdb/v0.0.40/user/{name} | Delete user
*SlurmdbApi* | [**slurmdb_v0040_delete_wckey**](docs/SlurmdbApi.md#slurmdb_v0040_delete_wckey) | **DELETE** /slurmdb/v0.0.40/wckey/{id} | Delete wckey
*SlurmdbApi* | [**slurmdb_v0040_get_account**](docs/SlurmdbApi.md#slurmdb_v0040_get_account) | **GET** /slurmdb/v0.0.40/account/{account_name} | Get account info
*SlurmdbApi* | [**slurmdb_v0040_get_accounts**](docs/SlurmdbApi.md#slurmdb_v0040_get_accounts) | **GET** /slurmdb/v0.0.40/accounts/ | Get account list
*SlurmdbApi* | [**slurmdb_v0040_get_association**](docs/SlurmdbApi.md#slurmdb_v0040_get_association) | **GET** /slurmdb/v0.0.40/association/ | Get association info
*SlurmdbApi* | [**slurmdb_v0040_get_associations**](docs/SlurmdbApi.md#slurmdb_v0040_get_associations) | **GET** /slurmdb/v0.0.40/associations/ | Get association list
*SlurmdbApi* | [**slurmdb_v0040_get_cluster**](docs/SlurmdbApi.md#slurmdb_v0040_get_cluster) | **GET** /slurmdb/v0.0.40/cluster/{cluster_name} | Get cluster info
*SlurmdbApi* | [**slurmdb_v0040_get_clusters**](docs/SlurmdbApi.md#slurmdb_v0040_get_clusters) | **GET** /slurmdb/v0.0.40/clusters/ | Get cluster list
*SlurmdbApi* | [**slurmdb_v0040_get_config**](docs/SlurmdbApi.md#slurmdb_v0040_get_config) | **GET** /slurmdb/v0.0.40/config | Dump all configuration information
*SlurmdbApi* | [**slurmdb_v0040_get_diag**](docs/SlurmdbApi.md#slurmdb_v0040_get_diag) | **GET** /slurmdb/v0.0.40/diag/ | Get slurmdb diagnostics
*SlurmdbApi* | [**slurmdb_v0040_get_instance**](docs/SlurmdbApi.md#slurmdb_v0040_get_instance) | **GET** /slurmdb/v0.0.40/instance/ | Get instance info
*SlurmdbApi* | [**slurmdb_v0040_get_instances**](docs/SlurmdbApi.md#slurmdb_v0040_get_instances) | **GET** /slurmdb/v0.0.40/instances/ | Get instance list
*SlurmdbApi* | [**slurmdb_v0040_get_job**](docs/SlurmdbApi.md#slurmdb_v0040_get_job) | **GET** /slurmdb/v0.0.40/job/{job_id} | Get job info
*SlurmdbApi* | [**slurmdb_v0040_get_jobs**](docs/SlurmdbApi.md#slurmdb_v0040_get_jobs) | **GET** /slurmdb/v0.0.40/jobs/ | Get job list
*SlurmdbApi* | [**slurmdb_v0040_get_qos**](docs/SlurmdbApi.md#slurmdb_v0040_get_qos) | **GET** /slurmdb/v0.0.40/qos/ | Get QOS list
*SlurmdbApi* | [**slurmdb_v0040_get_single_qos**](docs/SlurmdbApi.md#slurmdb_v0040_get_single_qos) | **GET** /slurmdb/v0.0.40/qos/{qos} | Get QOS info
*SlurmdbApi* | [**slurmdb_v0040_get_tres**](docs/SlurmdbApi.md#slurmdb_v0040_get_tres) | **GET** /slurmdb/v0.0.40/tres/ | Get TRES info
*SlurmdbApi* | [**slurmdb_v0040_get_user**](docs/SlurmdbApi.md#slurmdb_v0040_get_user) | **GET** /slurmdb/v0.0.40/user/{name} | Get user info
*SlurmdbApi* | [**slurmdb_v0040_get_users**](docs/SlurmdbApi.md#slurmdb_v0040_get_users) | **GET** /slurmdb/v0.0.40/users/ | Get user list
*SlurmdbApi* | [**slurmdb_v0040_get_wckey**](docs/SlurmdbApi.md#slurmdb_v0040_get_wckey) | **GET** /slurmdb/v0.0.40/wckey/{id} | Get wckey info
*SlurmdbApi* | [**slurmdb_v0040_get_wckeys**](docs/SlurmdbApi.md#slurmdb_v0040_get_wckeys) | **GET** /slurmdb/v0.0.40/wckeys/ | Get wckey list
*SlurmdbApi* | [**slurmdb_v0040_post_accounts**](docs/SlurmdbApi.md#slurmdb_v0040_post_accounts) | **POST** /slurmdb/v0.0.40/accounts/ | Add/update list of accounts
*SlurmdbApi* | [**slurmdb_v0040_post_accounts_association**](docs/SlurmdbApi.md#slurmdb_v0040_post_accounts_association) | **POST** /slurmdb/v0.0.40/accounts_association/ | Add accounts with conditional association
*SlurmdbApi* | [**slurmdb_v0040_post_associations**](docs/SlurmdbApi.md#slurmdb_v0040_post_associations) | **POST** /slurmdb/v0.0.40/associations/ | Set associations info
*SlurmdbApi* | [**slurmdb_v0040_post_clusters**](docs/SlurmdbApi.md#slurmdb_v0040_post_clusters) | **POST** /slurmdb/v0.0.40/clusters/ | Get cluster list
*SlurmdbApi* | [**slurmdb_v0040_post_config**](docs/SlurmdbApi.md#slurmdb_v0040_post_config) | **POST** /slurmdb/v0.0.40/config | Load all configuration information
*SlurmdbApi* | [**slurmdb_v0040_post_qos**](docs/SlurmdbApi.md#slurmdb_v0040_post_qos) | **POST** /slurmdb/v0.0.40/qos/ | Add or update QOSs
*SlurmdbApi* | [**slurmdb_v0040_post_tres**](docs/SlurmdbApi.md#slurmdb_v0040_post_tres) | **POST** /slurmdb/v0.0.40/tres/ | Add TRES
*SlurmdbApi* | [**slurmdb_v0040_post_users**](docs/SlurmdbApi.md#slurmdb_v0040_post_users) | **POST** /slurmdb/v0.0.40/users/ | Update users
*SlurmdbApi* | [**slurmdb_v0040_post_users_association**](docs/SlurmdbApi.md#slurmdb_v0040_post_users_association) | **POST** /slurmdb/v0.0.40/users_association/ | Add users with conditional association
*SlurmdbApi* | [**slurmdb_v0040_post_wckeys**](docs/SlurmdbApi.md#slurmdb_v0040_post_wckeys) | **POST** /slurmdb/v0.0.40/wckeys/ | Add or update wckeys
*SlurmdbApi* | [**slurmdb_v0041_delete_account**](docs/SlurmdbApi.md#slurmdb_v0041_delete_account) | **DELETE** /slurmdb/v0.0.41/account/{account_name} | Delete account
*SlurmdbApi* | [**slurmdb_v0041_delete_association**](docs/SlurmdbApi.md#slurmdb_v0041_delete_association) | **DELETE** /slurmdb/v0.0.41/association/ | Delete association
*SlurmdbApi* | [**slurmdb_v0041_delete_associations**](docs/SlurmdbApi.md#slurmdb_v0041_delete_associations) | **DELETE** /slurmdb/v0.0.41/associations/ | Delete associations
*SlurmdbApi* | [**slurmdb_v0041_delete_cluster**](docs/SlurmdbApi.md#slurmdb_v0041_delete_cluster) | **DELETE** /slurmdb/v0.0.41/cluster/{cluster_name} | Delete cluster
*SlurmdbApi* | [**slurmdb_v0041_delete_single_qos**](docs/SlurmdbApi.md#slurmdb_v0041_delete_single_qos) | **DELETE** /slurmdb/v0.0.41/qos/{qos} | Delete QOS
*SlurmdbApi* | [**slurmdb_v0041_delete_user**](docs/SlurmdbApi.md#slurmdb_v0041_delete_user) | **DELETE** /slurmdb/v0.0.41/user/{name} | Delete user
*SlurmdbApi* | [**slurmdb_v0041_delete_wckey**](docs/SlurmdbApi.md#slurmdb_v0041_delete_wckey) | **DELETE** /slurmdb/v0.0.41/wckey/{id} | Delete wckey
*SlurmdbApi* | [**slurmdb_v0041_get_account**](docs/SlurmdbApi.md#slurmdb_v0041_get_account) | **GET** /slurmdb/v0.0.41/account/{account_name} | Get account info
*SlurmdbApi* | [**slurmdb_v0041_get_accounts**](docs/SlurmdbApi.md#slurmdb_v0041_get_accounts) | **GET** /slurmdb/v0.0.41/accounts/ | Get account list
*SlurmdbApi* | [**slurmdb_v0041_get_association**](docs/SlurmdbApi.md#slurmdb_v0041_get_association) | **GET** /slurmdb/v0.0.41/association/ | Get association info
*SlurmdbApi* | [**slurmdb_v0041_get_associations**](docs/SlurmdbApi.md#slurmdb_v0041_get_associations) | **GET** /slurmdb/v0.0.41/associations/ | Get association list
*SlurmdbApi* | [**slurmdb_v0041_get_cluster**](docs/SlurmdbApi.md#slurmdb_v0041_get_cluster) | **GET** /slurmdb/v0.0.41/cluster/{cluster_name} | Get cluster info
*SlurmdbApi* | [**slurmdb_v0041_get_clusters**](docs/SlurmdbApi.md#slurmdb_v0041_get_clusters) | **GET** /slurmdb/v0.0.41/clusters/ | Get cluster list
*SlurmdbApi* | [**slurmdb_v0041_get_config**](docs/SlurmdbApi.md#slurmdb_v0041_get_config) | **GET** /slurmdb/v0.0.41/config | Dump all configuration information
*SlurmdbApi* | [**slurmdb_v0041_get_diag**](docs/SlurmdbApi.md#slurmdb_v0041_get_diag) | **GET** /slurmdb/v0.0.41/diag/ | Get slurmdb diagnostics
*SlurmdbApi* | [**slurmdb_v0041_get_instance**](docs/SlurmdbApi.md#slurmdb_v0041_get_instance) | **GET** /slurmdb/v0.0.41/instance/ | Get instance info
*SlurmdbApi* | [**slurmdb_v0041_get_instances**](docs/SlurmdbApi.md#slurmdb_v0041_get_instances) | **GET** /slurmdb/v0.0.41/instances/ | Get instance list
*SlurmdbApi* | [**slurmdb_v0041_get_job**](docs/SlurmdbApi.md#slurmdb_v0041_get_job) | **GET** /slurmdb/v0.0.41/job/{job_id} | Get job info
*SlurmdbApi* | [**slurmdb_v0041_get_jobs**](docs/SlurmdbApi.md#slurmdb_v0041_get_jobs) | **GET** /slurmdb/v0.0.41/jobs/ | Get job list
*SlurmdbApi* | [**slurmdb_v0041_get_qos**](docs/SlurmdbApi.md#slurmdb_v0041_get_qos) | **GET** /slurmdb/v0.0.41/qos/ | Get QOS list
*SlurmdbApi* | [**slurmdb_v0041_get_single_qos**](docs/SlurmdbApi.md#slurmdb_v0041_get_single_qos) | **GET** /slurmdb/v0.0.41/qos/{qos} | Get QOS info
*SlurmdbApi* | [**slurmdb_v0041_get_tres**](docs/SlurmdbApi.md#slurmdb_v0041_get_tres) | **GET** /slurmdb/v0.0.41/tres/ | Get TRES info
*SlurmdbApi* | [**slurmdb_v0041_get_user**](docs/SlurmdbApi.md#slurmdb_v0041_get_user) | **GET** /slurmdb/v0.0.41/user/{name} | Get user info
*SlurmdbApi* | [**slurmdb_v0041_get_users**](docs/SlurmdbApi.md#slurmdb_v0041_get_users) | **GET** /slurmdb/v0.0.41/users/ | Get user list
*SlurmdbApi* | [**slurmdb_v0041_get_wckey**](docs/SlurmdbApi.md#slurmdb_v0041_get_wckey) | **GET** /slurmdb/v0.0.41/wckey/{id} | Get wckey info
*SlurmdbApi* | [**slurmdb_v0041_get_wckeys**](docs/SlurmdbApi.md#slurmdb_v0041_get_wckeys) | **GET** /slurmdb/v0.0.41/wckeys/ | Get wckey list
*SlurmdbApi* | [**slurmdb_v0041_post_accounts**](docs/SlurmdbApi.md#slurmdb_v0041_post_accounts) | **POST** /slurmdb/v0.0.41/accounts/ | Add/update list of accounts
*SlurmdbApi* | [**slurmdb_v0041_post_accounts_association**](docs/SlurmdbApi.md#slurmdb_v0041_post_accounts_association) | **POST** /slurmdb/v0.0.41/accounts_association/ | Add accounts with conditional association
*SlurmdbApi* | [**slurmdb_v0041_post_associations**](docs/SlurmdbApi.md#slurmdb_v0041_post_associations) | **POST** /slurmdb/v0.0.41/associations/ | Set associations info
*SlurmdbApi* | [**slurmdb_v0041_post_clusters**](docs/SlurmdbApi.md#slurmdb_v0041_post_clusters) | **POST** /slurmdb/v0.0.41/clusters/ | Get cluster list
*SlurmdbApi* | [**slurmdb_v0041_post_config**](docs/SlurmdbApi.md#slurmdb_v0041_post_config) | **POST** /slurmdb/v0.0.41/config | Load all configuration information
*SlurmdbApi* | [**slurmdb_v0041_post_qos**](docs/SlurmdbApi.md#slurmdb_v0041_post_qos) | **POST** /slurmdb/v0.0.41/qos/ | Add or update QOSs
*SlurmdbApi* | [**slurmdb_v0041_post_tres**](docs/SlurmdbApi.md#slurmdb_v0041_post_tres) | **POST** /slurmdb/v0.0.41/tres/ | Add TRES
*SlurmdbApi* | [**slurmdb_v0041_post_users**](docs/SlurmdbApi.md#slurmdb_v0041_post_users) | **POST** /slurmdb/v0.0.41/users/ | Update users
*SlurmdbApi* | [**slurmdb_v0041_post_users_association**](docs/SlurmdbApi.md#slurmdb_v0041_post_users_association) | **POST** /slurmdb/v0.0.41/users_association/ | Add users with conditional association
*SlurmdbApi* | [**slurmdb_v0041_post_wckeys**](docs/SlurmdbApi.md#slurmdb_v0041_post_wckeys) | **POST** /slurmdb/v0.0.41/wckeys/ | Add or update wckeys
*SlurmdbApi* | [**slurmdb_v0042_delete_account**](docs/SlurmdbApi.md#slurmdb_v0042_delete_account) | **DELETE** /slurmdb/v0.0.42/account/{account_name} | Delete account
*SlurmdbApi* | [**slurmdb_v0042_delete_association**](docs/SlurmdbApi.md#slurmdb_v0042_delete_association) | **DELETE** /slurmdb/v0.0.42/association/ | Delete association
*SlurmdbApi* | [**slurmdb_v0042_delete_associations**](docs/SlurmdbApi.md#slurmdb_v0042_delete_associations) | **DELETE** /slurmdb/v0.0.42/associations/ | Delete associations
*SlurmdbApi* | [**slurmdb_v0042_delete_cluster**](docs/SlurmdbApi.md#slurmdb_v0042_delete_cluster) | **DELETE** /slurmdb/v0.0.42/cluster/{cluster_name} | Delete cluster
*SlurmdbApi* | [**slurmdb_v0042_delete_single_qos**](docs/SlurmdbApi.md#slurmdb_v0042_delete_single_qos) | **DELETE** /slurmdb/v0.0.42/qos/{qos} | Delete QOS
*SlurmdbApi* | [**slurmdb_v0042_delete_user**](docs/SlurmdbApi.md#slurmdb_v0042_delete_user) | **DELETE** /slurmdb/v0.0.42/user/{name} | Delete user
*SlurmdbApi* | [**slurmdb_v0042_delete_wckey**](docs/SlurmdbApi.md#slurmdb_v0042_delete_wckey) | **DELETE** /slurmdb/v0.0.42/wckey/{id} | Delete wckey
*SlurmdbApi* | [**slurmdb_v0042_get_account**](docs/SlurmdbApi.md#slurmdb_v0042_get_account) | **GET** /slurmdb/v0.0.42/account/{account_name} | Get account info
*SlurmdbApi* | [**slurmdb_v0042_get_accounts**](docs/SlurmdbApi.md#slurmdb_v0042_get_accounts) | **GET** /slurmdb/v0.0.42/accounts/ | Get account list
*SlurmdbApi* | [**slurmdb_v0042_get_association**](docs/SlurmdbApi.md#slurmdb_v0042_get_association) | **GET** /slurmdb/v0.0.42/association/ | Get association info
*SlurmdbApi* | [**slurmdb_v0042_get_associations**](docs/SlurmdbApi.md#slurmdb_v0042_get_associations) | **GET** /slurmdb/v0.0.42/associations/ | Get association list
*SlurmdbApi* | [**slurmdb_v0042_get_cluster**](docs/SlurmdbApi.md#slurmdb_v0042_get_cluster) | **GET** /slurmdb/v0.0.42/cluster/{cluster_name} | Get cluster info
*SlurmdbApi* | [**slurmdb_v0042_get_clusters**](docs/SlurmdbApi.md#slurmdb_v0042_get_clusters) | **GET** /slurmdb/v0.0.42/clusters/ | Get cluster list
*SlurmdbApi* | [**slurmdb_v0042_get_config**](docs/SlurmdbApi.md#slurmdb_v0042_get_config) | **GET** /slurmdb/v0.0.42/config | Dump all configuration information
*SlurmdbApi* | [**slurmdb_v0042_get_diag**](docs/SlurmdbApi.md#slurmdb_v0042_get_diag) | **GET** /slurmdb/v0.0.42/diag/ | Get slurmdb diagnostics
*SlurmdbApi* | [**slurmdb_v0042_get_instance**](docs/SlurmdbApi.md#slurmdb_v0042_get_instance) | **GET** /slurmdb/v0.0.42/instance/ | Get instance info
*SlurmdbApi* | [**slurmdb_v0042_get_instances**](docs/SlurmdbApi.md#slurmdb_v0042_get_instances) | **GET** /slurmdb/v0.0.42/instances/ | Get instance list
*SlurmdbApi* | [**slurmdb_v0042_get_job**](docs/SlurmdbApi.md#slurmdb_v0042_get_job) | **GET** /slurmdb/v0.0.42/job/{job_id} | Get job info
*SlurmdbApi* | [**slurmdb_v0042_get_jobs**](docs/SlurmdbApi.md#slurmdb_v0042_get_jobs) | **GET** /slurmdb/v0.0.42/jobs/ | Get job list
*SlurmdbApi* | [**slurmdb_v0042_get_ping**](docs/SlurmdbApi.md#slurmdb_v0042_get_ping) | **GET** /slurmdb/v0.0.42/ping/ | ping test
*SlurmdbApi* | [**slurmdb_v0042_get_qos**](docs/SlurmdbApi.md#slurmdb_v0042_get_qos) | **GET** /slurmdb/v0.0.42/qos/ | Get QOS list
*SlurmdbApi* | [**slurmdb_v0042_get_single_qos**](docs/SlurmdbApi.md#slurmdb_v0042_get_single_qos) | **GET** /slurmdb/v0.0.42/qos/{qos} | Get QOS info
*SlurmdbApi* | [**slurmdb_v0042_get_tres**](docs/SlurmdbApi.md#slurmdb_v0042_get_tres) | **GET** /slurmdb/v0.0.42/tres/ | Get TRES info
*SlurmdbApi* | [**slurmdb_v0042_get_user**](docs/SlurmdbApi.md#slurmdb_v0042_get_user) | **GET** /slurmdb/v0.0.42/user/{name} | Get user info
*SlurmdbApi* | [**slurmdb_v0042_get_users**](docs/SlurmdbApi.md#slurmdb_v0042_get_users) | **GET** /slurmdb/v0.0.42/users/ | Get user list
*SlurmdbApi* | [**slurmdb_v0042_get_wckey**](docs/SlurmdbApi.md#slurmdb_v0042_get_wckey) | **GET** /slurmdb/v0.0.42/wckey/{id} | Get wckey info
*SlurmdbApi* | [**slurmdb_v0042_get_wckeys**](docs/SlurmdbApi.md#slurmdb_v0042_get_wckeys) | **GET** /slurmdb/v0.0.42/wckeys/ | Get wckey list
*SlurmdbApi* | [**slurmdb_v0042_post_accounts**](docs/SlurmdbApi.md#slurmdb_v0042_post_accounts) | **POST** /slurmdb/v0.0.42/accounts/ | Add/update list of accounts
*SlurmdbApi* | [**slurmdb_v0042_post_accounts_association**](docs/SlurmdbApi.md#slurmdb_v0042_post_accounts_association) | **POST** /slurmdb/v0.0.42/accounts_association/ | Add accounts with conditional association
*SlurmdbApi* | [**slurmdb_v0042_post_associations**](docs/SlurmdbApi.md#slurmdb_v0042_post_associations) | **POST** /slurmdb/v0.0.42/associations/ | Set associations info
*SlurmdbApi* | [**slurmdb_v0042_post_clusters**](docs/SlurmdbApi.md#slurmdb_v0042_post_clusters) | **POST** /slurmdb/v0.0.42/clusters/ | Get cluster list
*SlurmdbApi* | [**slurmdb_v0042_post_config**](docs/SlurmdbApi.md#slurmdb_v0042_post_config) | **POST** /slurmdb/v0.0.42/config | Load all configuration information
*SlurmdbApi* | [**slurmdb_v0042_post_qos**](docs/SlurmdbApi.md#slurmdb_v0042_post_qos) | **POST** /slurmdb/v0.0.42/qos/ | Add or update QOSs
*SlurmdbApi* | [**slurmdb_v0042_post_tres**](docs/SlurmdbApi.md#slurmdb_v0042_post_tres) | **POST** /slurmdb/v0.0.42/tres/ | Add TRES
*SlurmdbApi* | [**slurmdb_v0042_post_users**](docs/SlurmdbApi.md#slurmdb_v0042_post_users) | **POST** /slurmdb/v0.0.42/users/ | Update users
*SlurmdbApi* | [**slurmdb_v0042_post_users_association**](docs/SlurmdbApi.md#slurmdb_v0042_post_users_association) | **POST** /slurmdb/v0.0.42/users_association/ | Add users with conditional association
*SlurmdbApi* | [**slurmdb_v0042_post_wckeys**](docs/SlurmdbApi.md#slurmdb_v0042_post_wckeys) | **POST** /slurmdb/v0.0.42/wckeys/ | Add or update wckeys


## Documentation For Models

 - [V0040Account](docs/V0040Account.md)
 - [V0040AccountShort](docs/V0040AccountShort.md)
 - [V0040Accounting](docs/V0040Accounting.md)
 - [V0040AccountingAllocated](docs/V0040AccountingAllocated.md)
 - [V0040AccountsAddCond](docs/V0040AccountsAddCond.md)
 - [V0040AcctGatherEnergy](docs/V0040AcctGatherEnergy.md)
 - [V0040Assoc](docs/V0040Assoc.md)
 - [V0040AssocMax](docs/V0040AssocMax.md)
 - [V0040AssocMaxJobs](docs/V0040AssocMaxJobs.md)
 - [V0040AssocMaxJobsPer](docs/V0040AssocMaxJobsPer.md)
 - [V0040AssocMaxPer](docs/V0040AssocMaxPer.md)
 - [V0040AssocMaxPerAccount](docs/V0040AssocMaxPerAccount.md)
 - [V0040AssocMaxTres](docs/V0040AssocMaxTres.md)
 - [V0040AssocMaxTresGroup](docs/V0040AssocMaxTresGroup.md)
 - [V0040AssocMaxTresMinutes](docs/V0040AssocMaxTresMinutes.md)
 - [V0040AssocMaxTresPer](docs/V0040AssocMaxTresPer.md)
 - [V0040AssocMin](docs/V0040AssocMin.md)
 - [V0040AssocRecSet](docs/V0040AssocRecSet.md)
 - [V0040AssocSharesObjWrap](docs/V0040AssocSharesObjWrap.md)
 - [V0040AssocSharesObjWrapFairshare](docs/V0040AssocSharesObjWrapFairshare.md)
 - [V0040AssocSharesObjWrapTres](docs/V0040AssocSharesObjWrapTres.md)
 - [V0040AssocShort](docs/V0040AssocShort.md)
 - [V0040BfExitFields](docs/V0040BfExitFields.md)
 - [V0040ClusterRec](docs/V0040ClusterRec.md)
 - [V0040ClusterRecAssociations](docs/V0040ClusterRecAssociations.md)
 - [V0040ControllerPing](docs/V0040ControllerPing.md)
 - [V0040Coord](docs/V0040Coord.md)
 - [V0040CronEntry](docs/V0040CronEntry.md)
 - [V0040Float64NoVal](docs/V0040Float64NoVal.md)
 - [V0040Instance](docs/V0040Instance.md)
 - [V0040Job](docs/V0040Job.md)
 - [V0040JobArray](docs/V0040JobArray.md)
 - [V0040JobArrayResponseMsgEntry](docs/V0040JobArrayResponseMsgEntry.md)
 - [V0040JobDescMsg](docs/V0040JobDescMsg.md)
 - [V0040JobDescMsgRlimits](docs/V0040JobDescMsgRlimits.md)
 - [V0040JobHet](docs/V0040JobHet.md)
 - [V0040JobInfo](docs/V0040JobInfo.md)
 - [V0040JobInfoPower](docs/V0040JobInfoPower.md)
 - [V0040JobRequired](docs/V0040JobRequired.md)
 - [V0040JobRes](docs/V0040JobRes.md)
 - [V0040JobState](docs/V0040JobState.md)
 - [V0040JobSubmitReq](docs/V0040JobSubmitReq.md)
 - [V0040JobSubmitResponseMsg](docs/V0040JobSubmitResponseMsg.md)
 - [V0040JobTime](docs/V0040JobTime.md)
 - [V0040JobTres](docs/V0040JobTres.md)
 - [V0040KillJobsMsg](docs/V0040KillJobsMsg.md)
 - [V0040KillJobsRespJob](docs/V0040KillJobsRespJob.md)
 - [V0040License](docs/V0040License.md)
 - [V0040Node](docs/V0040Node.md)
 - [V0040OpenapiAccountsAddCondResp](docs/V0040OpenapiAccountsAddCondResp.md)
 - [V0040OpenapiAccountsAddCondRespStr](docs/V0040OpenapiAccountsAddCondRespStr.md)
 - [V0040OpenapiAccountsRemovedResp](docs/V0040OpenapiAccountsRemovedResp.md)
 - [V0040OpenapiAccountsResp](docs/V0040OpenapiAccountsResp.md)
 - [V0040OpenapiAssocsRemovedResp](docs/V0040OpenapiAssocsRemovedResp.md)
 - [V0040OpenapiAssocsResp](docs/V0040OpenapiAssocsResp.md)
 - [V0040OpenapiClustersRemovedResp](docs/V0040OpenapiClustersRemovedResp.md)
 - [V0040OpenapiClustersResp](docs/V0040OpenapiClustersResp.md)
 - [V0040OpenapiDiagResp](docs/V0040OpenapiDiagResp.md)
 - [V0040OpenapiError](docs/V0040OpenapiError.md)
 - [V0040OpenapiInstancesResp](docs/V0040OpenapiInstancesResp.md)
 - [V0040OpenapiJobInfoResp](docs/V0040OpenapiJobInfoResp.md)
 - [V0040OpenapiJobPostResponse](docs/V0040OpenapiJobPostResponse.md)
 - [V0040OpenapiJobSubmitResponse](docs/V0040OpenapiJobSubmitResponse.md)
 - [V0040OpenapiKillJobsResp](docs/V0040OpenapiKillJobsResp.md)
 - [V0040OpenapiLicensesResp](docs/V0040OpenapiLicensesResp.md)
 - [V0040OpenapiMeta](docs/V0040OpenapiMeta.md)
 - [V0040OpenapiNodesResp](docs/V0040OpenapiNodesResp.md)
 - [V0040OpenapiPartitionResp](docs/V0040OpenapiPartitionResp.md)
 - [V0040OpenapiPingArrayResp](docs/V0040OpenapiPingArrayResp.md)
 - [V0040OpenapiReservationResp](docs/V0040OpenapiReservationResp.md)
 - [V0040OpenapiResp](docs/V0040OpenapiResp.md)
 - [V0040OpenapiSharesResp](docs/V0040OpenapiSharesResp.md)
 - [V0040OpenapiSlurmdbdConfigResp](docs/V0040OpenapiSlurmdbdConfigResp.md)
 - [V0040OpenapiSlurmdbdJobsResp](docs/V0040OpenapiSlurmdbdJobsResp.md)
 - [V0040OpenapiSlurmdbdQosRemovedResp](docs/V0040OpenapiSlurmdbdQosRemovedResp.md)
 - [V0040OpenapiSlurmdbdQosResp](docs/V0040OpenapiSlurmdbdQosResp.md)
 - [V0040OpenapiSlurmdbdStatsResp](docs/V0040OpenapiSlurmdbdStatsResp.md)
 - [V0040OpenapiTresResp](docs/V0040OpenapiTresResp.md)
 - [V0040OpenapiUsersAddCondResp](docs/V0040OpenapiUsersAddCondResp.md)
 - [V0040OpenapiUsersAddCondRespStr](docs/V0040OpenapiUsersAddCondRespStr.md)
 - [V0040OpenapiUsersResp](docs/V0040OpenapiUsersResp.md)
 - [V0040OpenapiWarning](docs/V0040OpenapiWarning.md)
 - [V0040OpenapiWckeyRemovedResp](docs/V0040OpenapiWckeyRemovedResp.md)
 - [V0040OpenapiWckeyResp](docs/V0040OpenapiWckeyResp.md)
 - [V0040PartitionInfo](docs/V0040PartitionInfo.md)
 - [V0040PartitionInfoDefaults](docs/V0040PartitionInfoDefaults.md)
 - [V0040PartitionInfoMaximums](docs/V0040PartitionInfoMaximums.md)
 - [V0040PartitionInfoMaximumsOversubscribe](docs/V0040PartitionInfoMaximumsOversubscribe.md)
 - [V0040PartitionInfoPartition](docs/V0040PartitionInfoPartition.md)
 - [V0040PartitionInfoTimeouts](docs/V0040PartitionInfoTimeouts.md)
 - [V0040ProcessExitCodeVerbose](docs/V0040ProcessExitCodeVerbose.md)
 - [V0040ProcessExitCodeVerboseSignal](docs/V0040ProcessExitCodeVerboseSignal.md)
 - [V0040Qos](docs/V0040Qos.md)
 - [V0040QosLimits](docs/V0040QosLimits.md)
 - [V0040QosLimitsMax](docs/V0040QosLimitsMax.md)
 - [V0040QosLimitsMaxActiveJobs](docs/V0040QosLimitsMaxActiveJobs.md)
 - [V0040QosLimitsMaxJobs](docs/V0040QosLimitsMaxJobs.md)
 - [V0040QosLimitsMaxJobsActiveJobs](docs/V0040QosLimitsMaxJobsActiveJobs.md)
 - [V0040QosLimitsMaxJobsActiveJobsPer](docs/V0040QosLimitsMaxJobsActiveJobsPer.md)
 - [V0040QosLimitsMaxTres](docs/V0040QosLimitsMaxTres.md)
 - [V0040QosLimitsMaxTresMinutes](docs/V0040QosLimitsMaxTresMinutes.md)
 - [V0040QosLimitsMaxTresMinutesPer](docs/V0040QosLimitsMaxTresMinutesPer.md)
 - [V0040QosLimitsMaxTresPer](docs/V0040QosLimitsMaxTresPer.md)
 - [V0040QosLimitsMaxWallClock](docs/V0040QosLimitsMaxWallClock.md)
 - [V0040QosLimitsMaxWallClockPer](docs/V0040QosLimitsMaxWallClockPer.md)
 - [V0040QosLimitsMin](docs/V0040QosLimitsMin.md)
 - [V0040QosLimitsMinTres](docs/V0040QosLimitsMinTres.md)
 - [V0040QosLimitsMinTresPer](docs/V0040QosLimitsMinTresPer.md)
 - [V0040QosPreempt](docs/V0040QosPreempt.md)
 - [V0040ReservationCoreSpec](docs/V0040ReservationCoreSpec.md)
 - [V0040ReservationInfo](docs/V0040ReservationInfo.md)
 - [V0040ReservationInfoPurgeCompleted](docs/V0040ReservationInfoPurgeCompleted.md)
 - [V0040RollupStatsInner](docs/V0040RollupStatsInner.md)
 - [V0040ScheduleExitFields](docs/V0040ScheduleExitFields.md)
 - [V0040SharesFloat128Tres](docs/V0040SharesFloat128Tres.md)
 - [V0040SharesRespMsg](docs/V0040SharesRespMsg.md)
 - [V0040SharesUint64Tres](docs/V0040SharesUint64Tres.md)
 - [V0040StatsMsg](docs/V0040StatsMsg.md)
 - [V0040StatsMsgRpcsByTypeInner](docs/V0040StatsMsgRpcsByTypeInner.md)
 - [V0040StatsMsgRpcsByUserInner](docs/V0040StatsMsgRpcsByUserInner.md)
 - [V0040StatsRec](docs/V0040StatsRec.md)
 - [V0040StatsRpc](docs/V0040StatsRpc.md)
 - [V0040StatsUser](docs/V0040StatsUser.md)
 - [V0040Step](docs/V0040Step.md)
 - [V0040StepCPU](docs/V0040StepCPU.md)
 - [V0040StepCPURequestedFrequency](docs/V0040StepCPURequestedFrequency.md)
 - [V0040StepNodes](docs/V0040StepNodes.md)
 - [V0040StepStatistics](docs/V0040StepStatistics.md)
 - [V0040StepStatisticsEnergy](docs/V0040StepStatisticsEnergy.md)
 - [V0040StepStep](docs/V0040StepStep.md)
 - [V0040StepTime](docs/V0040StepTime.md)
 - [V0040StepTres](docs/V0040StepTres.md)
 - [V0040StepTresConsumed](docs/V0040StepTresConsumed.md)
 - [V0040StepTresRequested](docs/V0040StepTresRequested.md)
 - [V0040Tres](docs/V0040Tres.md)
 - [V0040Uint16NoVal](docs/V0040Uint16NoVal.md)
 - [V0040Uint32NoVal](docs/V0040Uint32NoVal.md)
 - [V0040Uint64NoVal](docs/V0040Uint64NoVal.md)
 - [V0040UpdateNodeMsg](docs/V0040UpdateNodeMsg.md)
 - [V0040User](docs/V0040User.md)
 - [V0040UserDefault](docs/V0040UserDefault.md)
 - [V0040UserShort](docs/V0040UserShort.md)
 - [V0040UsersAddCond](docs/V0040UsersAddCond.md)
 - [V0040Wckey](docs/V0040Wckey.md)
 - [V0040WckeyTagStruct](docs/V0040WckeyTagStruct.md)
 - [V0041JobAllocReq](docs/V0041JobAllocReq.md)
 - [V0041JobDescMsg](docs/V0041JobDescMsg.md)
 - [V0041JobDescMsgBeginTime](docs/V0041JobDescMsgBeginTime.md)
 - [V0041JobDescMsgCrontab](docs/V0041JobDescMsgCrontab.md)
 - [V0041JobDescMsgDistributionPlaneSize](docs/V0041JobDescMsgDistributionPlaneSize.md)
 - [V0041JobDescMsgKillWarningDelay](docs/V0041JobDescMsgKillWarningDelay.md)
 - [V0041JobDescMsgRequiredSwitches](docs/V0041JobDescMsgRequiredSwitches.md)
 - [V0041JobDescMsgRlimits](docs/V0041JobDescMsgRlimits.md)
 - [V0041JobDescMsgRlimitsAs](docs/V0041JobDescMsgRlimitsAs.md)
 - [V0041JobDescMsgRlimitsCore](docs/V0041JobDescMsgRlimitsCore.md)
 - [V0041JobDescMsgRlimitsCpu](docs/V0041JobDescMsgRlimitsCpu.md)
 - [V0041JobDescMsgRlimitsData](docs/V0041JobDescMsgRlimitsData.md)
 - [V0041JobDescMsgRlimitsFsize](docs/V0041JobDescMsgRlimitsFsize.md)
 - [V0041JobDescMsgRlimitsMemlock](docs/V0041JobDescMsgRlimitsMemlock.md)
 - [V0041JobDescMsgRlimitsNofile](docs/V0041JobDescMsgRlimitsNofile.md)
 - [V0041JobDescMsgRlimitsNproc](docs/V0041JobDescMsgRlimitsNproc.md)
 - [V0041JobDescMsgRlimitsRss](docs/V0041JobDescMsgRlimitsRss.md)
 - [V0041JobDescMsgRlimitsStack](docs/V0041JobDescMsgRlimitsStack.md)
 - [V0041JobDescMsgSegmentSize](docs/V0041JobDescMsgSegmentSize.md)
 - [V0041JobDescMsgTimeMinimum](docs/V0041JobDescMsgTimeMinimum.md)
 - [V0041JobSubmitReq](docs/V0041JobSubmitReq.md)
 - [V0041KillJobsMsg](docs/V0041KillJobsMsg.md)
 - [V0041OpenapiAccountsAddCondResp](docs/V0041OpenapiAccountsAddCondResp.md)
 - [V0041OpenapiAccountsAddCondRespAccount](docs/V0041OpenapiAccountsAddCondRespAccount.md)
 - [V0041OpenapiAccountsAddCondRespAssociationCondition](docs/V0041OpenapiAccountsAddCondRespAssociationCondition.md)
 - [V0041OpenapiAccountsAddCondRespStr](docs/V0041OpenapiAccountsAddCondRespStr.md)
 - [V0041OpenapiAccountsRemovedResp](docs/V0041OpenapiAccountsRemovedResp.md)
 - [V0041OpenapiAccountsResp](docs/V0041OpenapiAccountsResp.md)
 - [V0041OpenapiAssocsRemovedResp](docs/V0041OpenapiAssocsRemovedResp.md)
 - [V0041OpenapiAssocsResp](docs/V0041OpenapiAssocsResp.md)
 - [V0041OpenapiClustersRemovedResp](docs/V0041OpenapiClustersRemovedResp.md)
 - [V0041OpenapiClustersResp](docs/V0041OpenapiClustersResp.md)
 - [V0041OpenapiDiagResp](docs/V0041OpenapiDiagResp.md)
 - [V0041OpenapiDiagRespStatistics](docs/V0041OpenapiDiagRespStatistics.md)
 - [V0041OpenapiDiagRespStatisticsBfExit](docs/V0041OpenapiDiagRespStatisticsBfExit.md)
 - [V0041OpenapiDiagRespStatisticsBfWhenLastCycle](docs/V0041OpenapiDiagRespStatisticsBfWhenLastCycle.md)
 - [V0041OpenapiDiagRespStatisticsJobStatesTs](docs/V0041OpenapiDiagRespStatisticsJobStatesTs.md)
 - [V0041OpenapiDiagRespStatisticsPendingRpcsByHostlistInner](docs/V0041OpenapiDiagRespStatisticsPendingRpcsByHostlistInner.md)
 - [V0041OpenapiDiagRespStatisticsPendingRpcsInner](docs/V0041OpenapiDiagRespStatisticsPendingRpcsInner.md)
 - [V0041OpenapiDiagRespStatisticsReqTime](docs/V0041OpenapiDiagRespStatisticsReqTime.md)
 - [V0041OpenapiDiagRespStatisticsReqTimeStart](docs/V0041OpenapiDiagRespStatisticsReqTimeStart.md)
 - [V0041OpenapiDiagRespStatisticsRpcsByMessageTypeInner](docs/V0041OpenapiDiagRespStatisticsRpcsByMessageTypeInner.md)
 - [V0041OpenapiDiagRespStatisticsRpcsByMessageTypeInnerAverageTime](docs/V0041OpenapiDiagRespStatisticsRpcsByMessageTypeInnerAverageTime.md)
 - [V0041OpenapiDiagRespStatisticsRpcsByUserInner](docs/V0041OpenapiDiagRespStatisticsRpcsByUserInner.md)
 - [V0041OpenapiDiagRespStatisticsScheduleExit](docs/V0041OpenapiDiagRespStatisticsScheduleExit.md)
 - [V0041OpenapiInstancesResp](docs/V0041OpenapiInstancesResp.md)
 - [V0041OpenapiJobAllocResp](docs/V0041OpenapiJobAllocResp.md)
 - [V0041OpenapiJobInfoResp](docs/V0041OpenapiJobInfoResp.md)
 - [V0041OpenapiJobInfoRespJobsInner](docs/V0041OpenapiJobInfoRespJobsInner.md)
 - [V0041OpenapiJobInfoRespJobsInnerAccrueTime](docs/V0041OpenapiJobInfoRespJobsInnerAccrueTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerArrayJobId](docs/V0041OpenapiJobInfoRespJobsInnerArrayJobId.md)
 - [V0041OpenapiJobInfoRespJobsInnerArrayMaxTasks](docs/V0041OpenapiJobInfoRespJobsInnerArrayMaxTasks.md)
 - [V0041OpenapiJobInfoRespJobsInnerBillableTres](docs/V0041OpenapiJobInfoRespJobsInnerBillableTres.md)
 - [V0041OpenapiJobInfoRespJobsInnerCoresPerSocket](docs/V0041OpenapiJobInfoRespJobsInnerCoresPerSocket.md)
 - [V0041OpenapiJobInfoRespJobsInnerCpuFrequencyGovernor](docs/V0041OpenapiJobInfoRespJobsInnerCpuFrequencyGovernor.md)
 - [V0041OpenapiJobInfoRespJobsInnerCpuFrequencyMaximum](docs/V0041OpenapiJobInfoRespJobsInnerCpuFrequencyMaximum.md)
 - [V0041OpenapiJobInfoRespJobsInnerCpuFrequencyMinimum](docs/V0041OpenapiJobInfoRespJobsInnerCpuFrequencyMinimum.md)
 - [V0041OpenapiJobInfoRespJobsInnerCpus](docs/V0041OpenapiJobInfoRespJobsInnerCpus.md)
 - [V0041OpenapiJobInfoRespJobsInnerCpusPerTask](docs/V0041OpenapiJobInfoRespJobsInnerCpusPerTask.md)
 - [V0041OpenapiJobInfoRespJobsInnerDeadline](docs/V0041OpenapiJobInfoRespJobsInnerDeadline.md)
 - [V0041OpenapiJobInfoRespJobsInnerDelayBoot](docs/V0041OpenapiJobInfoRespJobsInnerDelayBoot.md)
 - [V0041OpenapiJobInfoRespJobsInnerEligibleTime](docs/V0041OpenapiJobInfoRespJobsInnerEligibleTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerEndTime](docs/V0041OpenapiJobInfoRespJobsInnerEndTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerExitCode](docs/V0041OpenapiJobInfoRespJobsInnerExitCode.md)
 - [V0041OpenapiJobInfoRespJobsInnerHetJobId](docs/V0041OpenapiJobInfoRespJobsInnerHetJobId.md)
 - [V0041OpenapiJobInfoRespJobsInnerJobResources](docs/V0041OpenapiJobInfoRespJobsInnerJobResources.md)
 - [V0041OpenapiJobInfoRespJobsInnerJobResourcesNodes](docs/V0041OpenapiJobInfoRespJobsInnerJobResourcesNodes.md)
 - [V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner](docs/V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner.md)
 - [V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInner](docs/V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInner.md)
 - [V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInnerCoresInner](docs/V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInnerCoresInner.md)
 - [V0041OpenapiJobInfoRespJobsInnerJobResourcesThreadsPerCore](docs/V0041OpenapiJobInfoRespJobsInnerJobResourcesThreadsPerCore.md)
 - [V0041OpenapiJobInfoRespJobsInnerLastSchedEvaluation](docs/V0041OpenapiJobInfoRespJobsInnerLastSchedEvaluation.md)
 - [V0041OpenapiJobInfoRespJobsInnerMaxCpus](docs/V0041OpenapiJobInfoRespJobsInnerMaxCpus.md)
 - [V0041OpenapiJobInfoRespJobsInnerMaxNodes](docs/V0041OpenapiJobInfoRespJobsInnerMaxNodes.md)
 - [V0041OpenapiJobInfoRespJobsInnerMinimumCpusPerNode](docs/V0041OpenapiJobInfoRespJobsInnerMinimumCpusPerNode.md)
 - [V0041OpenapiJobInfoRespJobsInnerMinimumTmpDiskPerNode](docs/V0041OpenapiJobInfoRespJobsInnerMinimumTmpDiskPerNode.md)
 - [V0041OpenapiJobInfoRespJobsInnerNodeCount](docs/V0041OpenapiJobInfoRespJobsInnerNodeCount.md)
 - [V0041OpenapiJobInfoRespJobsInnerPreSusTime](docs/V0041OpenapiJobInfoRespJobsInnerPreSusTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerPreemptTime](docs/V0041OpenapiJobInfoRespJobsInnerPreemptTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerPreemptableTime](docs/V0041OpenapiJobInfoRespJobsInnerPreemptableTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerResizeTime](docs/V0041OpenapiJobInfoRespJobsInnerResizeTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerSocketsPerNode](docs/V0041OpenapiJobInfoRespJobsInnerSocketsPerNode.md)
 - [V0041OpenapiJobInfoRespJobsInnerStartTime](docs/V0041OpenapiJobInfoRespJobsInnerStartTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerSubmitTime](docs/V0041OpenapiJobInfoRespJobsInnerSubmitTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerSuspendTime](docs/V0041OpenapiJobInfoRespJobsInnerSuspendTime.md)
 - [V0041OpenapiJobInfoRespJobsInnerTasks](docs/V0041OpenapiJobInfoRespJobsInnerTasks.md)
 - [V0041OpenapiJobInfoRespJobsInnerTasksPerBoard](docs/V0041OpenapiJobInfoRespJobsInnerTasksPerBoard.md)
 - [V0041OpenapiJobInfoRespJobsInnerTasksPerCore](docs/V0041OpenapiJobInfoRespJobsInnerTasksPerCore.md)
 - [V0041OpenapiJobInfoRespJobsInnerTasksPerNode](docs/V0041OpenapiJobInfoRespJobsInnerTasksPerNode.md)
 - [V0041OpenapiJobInfoRespJobsInnerTasksPerSocket](docs/V0041OpenapiJobInfoRespJobsInnerTasksPerSocket.md)
 - [V0041OpenapiJobInfoRespJobsInnerTasksPerTres](docs/V0041OpenapiJobInfoRespJobsInnerTasksPerTres.md)
 - [V0041OpenapiJobInfoRespJobsInnerThreadsPerCore](docs/V0041OpenapiJobInfoRespJobsInnerThreadsPerCore.md)
 - [V0041OpenapiJobInfoRespLastBackfill](docs/V0041OpenapiJobInfoRespLastBackfill.md)
 - [V0041OpenapiJobInfoRespLastUpdate](docs/V0041OpenapiJobInfoRespLastUpdate.md)
 - [V0041OpenapiJobPostResponse](docs/V0041OpenapiJobPostResponse.md)
 - [V0041OpenapiJobPostResponseResultsInner](docs/V0041OpenapiJobPostResponseResultsInner.md)
 - [V0041OpenapiJobSubmitResponse](docs/V0041OpenapiJobSubmitResponse.md)
 - [V0041OpenapiJobSubmitResponseResult](docs/V0041OpenapiJobSubmitResponseResult.md)
 - [V0041OpenapiKillJobsResp](docs/V0041OpenapiKillJobsResp.md)
 - [V0041OpenapiKillJobsRespStatusInner](docs/V0041OpenapiKillJobsRespStatusInner.md)
 - [V0041OpenapiKillJobsRespStatusInnerJobId](docs/V0041OpenapiKillJobsRespStatusInnerJobId.md)
 - [V0041OpenapiLicensesResp](docs/V0041OpenapiLicensesResp.md)
 - [V0041OpenapiLicensesRespLastUpdate](docs/V0041OpenapiLicensesRespLastUpdate.md)
 - [V0041OpenapiLicensesRespLicensesInner](docs/V0041OpenapiLicensesRespLicensesInner.md)
 - [V0041OpenapiNodesResp](docs/V0041OpenapiNodesResp.md)
 - [V0041OpenapiNodesRespLastUpdate](docs/V0041OpenapiNodesRespLastUpdate.md)
 - [V0041OpenapiNodesRespNodesInner](docs/V0041OpenapiNodesRespNodesInner.md)
 - [V0041OpenapiNodesRespNodesInnerBootTime](docs/V0041OpenapiNodesRespNodesInnerBootTime.md)
 - [V0041OpenapiNodesRespNodesInnerEnergy](docs/V0041OpenapiNodesRespNodesInnerEnergy.md)
 - [V0041OpenapiNodesRespNodesInnerEnergyCurrentWatts](docs/V0041OpenapiNodesRespNodesInnerEnergyCurrentWatts.md)
 - [V0041OpenapiNodesRespNodesInnerFreeMem](docs/V0041OpenapiNodesRespNodesInnerFreeMem.md)
 - [V0041OpenapiNodesRespNodesInnerLastBusy](docs/V0041OpenapiNodesRespNodesInnerLastBusy.md)
 - [V0041OpenapiNodesRespNodesInnerReasonChangedAt](docs/V0041OpenapiNodesRespNodesInnerReasonChangedAt.md)
 - [V0041OpenapiNodesRespNodesInnerResumeAfter](docs/V0041OpenapiNodesRespNodesInnerResumeAfter.md)
 - [V0041OpenapiNodesRespNodesInnerSlurmdStartTime](docs/V0041OpenapiNodesRespNodesInnerSlurmdStartTime.md)
 - [V0041OpenapiPartitionResp](docs/V0041OpenapiPartitionResp.md)
 - [V0041OpenapiPartitionRespLastUpdate](docs/V0041OpenapiPartitionRespLastUpdate.md)
 - [V0041OpenapiPartitionRespPartitionsInner](docs/V0041OpenapiPartitionRespPartitionsInner.md)
 - [V0041OpenapiPartitionRespPartitionsInnerDefaults](docs/V0041OpenapiPartitionRespPartitionsInnerDefaults.md)
 - [V0041OpenapiPartitionRespPartitionsInnerDefaultsPartitionMemoryPerCpu](docs/V0041OpenapiPartitionRespPartitionsInnerDefaultsPartitionMemoryPerCpu.md)
 - [V0041OpenapiPartitionRespPartitionsInnerDefaultsPartitionMemoryPerNode](docs/V0041OpenapiPartitionRespPartitionsInnerDefaultsPartitionMemoryPerNode.md)
 - [V0041OpenapiPartitionRespPartitionsInnerDefaultsTime](docs/V0041OpenapiPartitionRespPartitionsInnerDefaultsTime.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximums](docs/V0041OpenapiPartitionRespPartitionsInnerMaximums.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsCpusPerNode](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsCpusPerNode.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsCpusPerSocket](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsCpusPerSocket.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsNodes](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsNodes.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsOverTimeLimit](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsOverTimeLimit.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsOversubscribe](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsOversubscribe.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsPartitionMemoryPerCpu](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsPartitionMemoryPerCpu.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsPartitionMemoryPerNode](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsPartitionMemoryPerNode.md)
 - [V0041OpenapiPartitionRespPartitionsInnerMaximumsTime](docs/V0041OpenapiPartitionRespPartitionsInnerMaximumsTime.md)
 - [V0041OpenapiPartitionRespPartitionsInnerPartition](docs/V0041OpenapiPartitionRespPartitionsInnerPartition.md)
 - [V0041OpenapiPartitionRespPartitionsInnerSuspendTime](docs/V0041OpenapiPartitionRespPartitionsInnerSuspendTime.md)
 - [V0041OpenapiPartitionRespPartitionsInnerTimeouts](docs/V0041OpenapiPartitionRespPartitionsInnerTimeouts.md)
 - [V0041OpenapiPartitionRespPartitionsInnerTimeoutsResume](docs/V0041OpenapiPartitionRespPartitionsInnerTimeoutsResume.md)
 - [V0041OpenapiPartitionRespPartitionsInnerTimeoutsSuspend](docs/V0041OpenapiPartitionRespPartitionsInnerTimeoutsSuspend.md)
 - [V0041OpenapiPingArrayResp](docs/V0041OpenapiPingArrayResp.md)
 - [V0041OpenapiPingArrayRespPingsInner](docs/V0041OpenapiPingArrayRespPingsInner.md)
 - [V0041OpenapiReservationResp](docs/V0041OpenapiReservationResp.md)
 - [V0041OpenapiReservationRespLastUpdate](docs/V0041OpenapiReservationRespLastUpdate.md)
 - [V0041OpenapiReservationRespReservationsInner](docs/V0041OpenapiReservationRespReservationsInner.md)
 - [V0041OpenapiReservationRespReservationsInnerCoreSpecializationsInner](docs/V0041OpenapiReservationRespReservationsInnerCoreSpecializationsInner.md)
 - [V0041OpenapiReservationRespReservationsInnerEndTime](docs/V0041OpenapiReservationRespReservationsInnerEndTime.md)
 - [V0041OpenapiReservationRespReservationsInnerPurgeCompleted](docs/V0041OpenapiReservationRespReservationsInnerPurgeCompleted.md)
 - [V0041OpenapiReservationRespReservationsInnerPurgeCompletedTime](docs/V0041OpenapiReservationRespReservationsInnerPurgeCompletedTime.md)
 - [V0041OpenapiReservationRespReservationsInnerStartTime](docs/V0041OpenapiReservationRespReservationsInnerStartTime.md)
 - [V0041OpenapiReservationRespReservationsInnerWatts](docs/V0041OpenapiReservationRespReservationsInnerWatts.md)
 - [V0041OpenapiResp](docs/V0041OpenapiResp.md)
 - [V0041OpenapiSharesResp](docs/V0041OpenapiSharesResp.md)
 - [V0041OpenapiSharesRespShares](docs/V0041OpenapiSharesRespShares.md)
 - [V0041OpenapiSharesRespSharesSharesInner](docs/V0041OpenapiSharesRespSharesSharesInner.md)
 - [V0041OpenapiSharesRespSharesSharesInnerShares](docs/V0041OpenapiSharesRespSharesSharesInnerShares.md)
 - [V0041OpenapiSharesRespSharesSharesInnerSharesNormalized](docs/V0041OpenapiSharesRespSharesSharesInnerSharesNormalized.md)
 - [V0041OpenapiSharesRespSharesSharesInnerTres](docs/V0041OpenapiSharesRespSharesSharesInnerTres.md)
 - [V0041OpenapiSharesRespSharesSharesInnerTresRunSecondsInner](docs/V0041OpenapiSharesRespSharesSharesInnerTresRunSecondsInner.md)
 - [V0041OpenapiSharesRespSharesSharesInnerTresRunSecondsInnerValue](docs/V0041OpenapiSharesRespSharesSharesInnerTresRunSecondsInnerValue.md)
 - [V0041OpenapiSharesRespSharesSharesInnerTresUsageInner](docs/V0041OpenapiSharesRespSharesSharesInnerTresUsageInner.md)
 - [V0041OpenapiSharesRespSharesSharesInnerUsageNormalized](docs/V0041OpenapiSharesRespSharesSharesInnerUsageNormalized.md)
 - [V0041OpenapiSlurmdbdConfigResp](docs/V0041OpenapiSlurmdbdConfigResp.md)
 - [V0041OpenapiSlurmdbdConfigRespAccountsInner](docs/V0041OpenapiSlurmdbdConfigRespAccountsInner.md)
 - [V0041OpenapiSlurmdbdConfigRespAccountsInnerAssociationsInner](docs/V0041OpenapiSlurmdbdConfigRespAccountsInnerAssociationsInner.md)
 - [V0041OpenapiSlurmdbdConfigRespAccountsInnerCoordinatorsInner](docs/V0041OpenapiSlurmdbdConfigRespAccountsInnerCoordinatorsInner.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInner](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInner.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsAccruing](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsAccruing.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsPer](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsPer.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsPerSubmitted](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsPerSubmitted.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsTotal](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsTotal.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxPer](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxPer.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxPerAccount](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxPerAccount.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTres](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTres.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresGroup](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresGroup.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresMinutes](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresMinutes.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresMinutesPer](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresMinutesPer.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresPer](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresPer.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerMin](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerMin.md)
 - [V0041OpenapiSlurmdbdConfigRespAssociationsInnerPriority](docs/V0041OpenapiSlurmdbdConfigRespAssociationsInnerPriority.md)
 - [V0041OpenapiSlurmdbdConfigRespClustersInner](docs/V0041OpenapiSlurmdbdConfigRespClustersInner.md)
 - [V0041OpenapiSlurmdbdConfigRespClustersInnerAssociations](docs/V0041OpenapiSlurmdbdConfigRespClustersInnerAssociations.md)
 - [V0041OpenapiSlurmdbdConfigRespClustersInnerAssociationsRoot](docs/V0041OpenapiSlurmdbdConfigRespClustersInnerAssociationsRoot.md)
 - [V0041OpenapiSlurmdbdConfigRespInstancesInner](docs/V0041OpenapiSlurmdbdConfigRespInstancesInner.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInner](docs/V0041OpenapiSlurmdbdConfigRespQosInner.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimits](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimits.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsFactor](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsFactor.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMax](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMax.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruing](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruing.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPerAccount](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPerAccount.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPerUser](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPerUser.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobs](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobs.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobsAccruing](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobsAccruing.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobsCount](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobsCount.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobs](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobs.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobs](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobs.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPerAccount](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPerAccount.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPerUser](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPerUser.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPerAccount](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPerAccount.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPerUser](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPerUser.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTres](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTres.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutesPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutesPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClock](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClock.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPerJob](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPerJob.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPerQos](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPerQos.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMin](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMin.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinPriorityThreshold](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinPriorityThreshold.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinTres](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinTres.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinTresPer](docs/V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinTresPer.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerPreempt](docs/V0041OpenapiSlurmdbdConfigRespQosInnerPreempt.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerPreemptExemptTime](docs/V0041OpenapiSlurmdbdConfigRespQosInnerPreemptExemptTime.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerPriority](docs/V0041OpenapiSlurmdbdConfigRespQosInnerPriority.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerUsageFactor](docs/V0041OpenapiSlurmdbdConfigRespQosInnerUsageFactor.md)
 - [V0041OpenapiSlurmdbdConfigRespQosInnerUsageThreshold](docs/V0041OpenapiSlurmdbdConfigRespQosInnerUsageThreshold.md)
 - [V0041OpenapiSlurmdbdConfigRespUsersInner](docs/V0041OpenapiSlurmdbdConfigRespUsersInner.md)
 - [V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInner](docs/V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInner.md)
 - [V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner](docs/V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner.md)
 - [V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInnerTRES](docs/V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInnerTRES.md)
 - [V0041OpenapiSlurmdbdJobsResp](docs/V0041OpenapiSlurmdbdJobsResp.md)
 - [V0041OpenapiSlurmdbdJobsRespErrorsInner](docs/V0041OpenapiSlurmdbdJobsRespErrorsInner.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInner](docs/V0041OpenapiSlurmdbdJobsRespJobsInner.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerArray](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerArray.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerArrayTaskId](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerArrayTaskId.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerAssociation](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerAssociation.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeReturnCode](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeReturnCode.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignal](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignal.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignalId](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignalId.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerExitCode](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerExitCode.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerHet](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerHet.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerHetJobOffset](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerHetJobOffset.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerPriority](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerPriority.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerRequired](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerRequired.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerRequiredMemoryPerCpu](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerRequiredMemoryPerCpu.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerRequiredMemoryPerNode](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerRequiredMemoryPerNode.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerState](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerState.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInner](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInner.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPU](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPU.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequency](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequency.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequencyMax](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequencyMax.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequencyMin](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequencyMin.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerNodes](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerNodes.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatisticsEnergy](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatisticsEnergy.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatisticsEnergyConsumed](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatisticsEnergyConsumed.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTime](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTime.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTimeEnd](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTimeEnd.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTimeStart](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTimeStart.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTres](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTres.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresRequested](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresRequested.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresRequestedMaxInner](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresRequestedMaxInner.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerTime](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerTime.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerTimeLimit](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerTimeLimit.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerTimePlanned](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerTimePlanned.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerTres](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerTres.md)
 - [V0041OpenapiSlurmdbdJobsRespJobsInnerWckey](docs/V0041OpenapiSlurmdbdJobsRespJobsInnerWckey.md)
 - [V0041OpenapiSlurmdbdJobsRespMeta](docs/V0041OpenapiSlurmdbdJobsRespMeta.md)
 - [V0041OpenapiSlurmdbdJobsRespWarningsInner](docs/V0041OpenapiSlurmdbdJobsRespWarningsInner.md)
 - [V0041OpenapiSlurmdbdQosRemovedResp](docs/V0041OpenapiSlurmdbdQosRemovedResp.md)
 - [V0041OpenapiSlurmdbdQosResp](docs/V0041OpenapiSlurmdbdQosResp.md)
 - [V0041OpenapiSlurmdbdStatsResp](docs/V0041OpenapiSlurmdbdStatsResp.md)
 - [V0041OpenapiSlurmdbdStatsRespStatistics](docs/V0041OpenapiSlurmdbdStatsRespStatistics.md)
 - [V0041OpenapiSlurmdbdStatsRespStatisticsRPCsInner](docs/V0041OpenapiSlurmdbdStatsRespStatisticsRPCsInner.md)
 - [V0041OpenapiSlurmdbdStatsRespStatisticsRollups](docs/V0041OpenapiSlurmdbdStatsRespStatisticsRollups.md)
 - [V0041OpenapiSlurmdbdStatsRespStatisticsUsersInner](docs/V0041OpenapiSlurmdbdStatsRespStatisticsUsersInner.md)
 - [V0041OpenapiTresResp](docs/V0041OpenapiTresResp.md)
 - [V0041OpenapiUsersAddCondResp](docs/V0041OpenapiUsersAddCondResp.md)
 - [V0041OpenapiUsersAddCondRespAssociationCondition](docs/V0041OpenapiUsersAddCondRespAssociationCondition.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociation](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociation.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpjobs](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpjobs.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpjobsaccrue](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpjobsaccrue.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpsubmitjobs](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpsubmitjobs.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpwall](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpwall.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxjobs](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxjobs.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxjobsaccrue](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxjobsaccrue.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxsubmitjobs](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxsubmitjobs.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxwalldurationperjob](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxwalldurationperjob.md)
 - [V0041OpenapiUsersAddCondRespAssociationConditionAssociationMinpriothresh](docs/V0041OpenapiUsersAddCondRespAssociationConditionAssociationMinpriothresh.md)
 - [V0041OpenapiUsersAddCondRespStr](docs/V0041OpenapiUsersAddCondRespStr.md)
 - [V0041OpenapiUsersAddCondRespUser](docs/V0041OpenapiUsersAddCondRespUser.md)
 - [V0041OpenapiUsersResp](docs/V0041OpenapiUsersResp.md)
 - [V0041OpenapiWckeyRemovedResp](docs/V0041OpenapiWckeyRemovedResp.md)
 - [V0041OpenapiWckeyResp](docs/V0041OpenapiWckeyResp.md)
 - [V0041UpdateNodeMsg](docs/V0041UpdateNodeMsg.md)
 - [V0041UpdateNodeMsgResumeAfter](docs/V0041UpdateNodeMsgResumeAfter.md)
 - [V0041UpdateNodeMsgWeight](docs/V0041UpdateNodeMsgWeight.md)
 - [V0042Account](docs/V0042Account.md)
 - [V0042AccountShort](docs/V0042AccountShort.md)
 - [V0042Accounting](docs/V0042Accounting.md)
 - [V0042AccountingAllocated](docs/V0042AccountingAllocated.md)
 - [V0042AccountsAddCond](docs/V0042AccountsAddCond.md)
 - [V0042AcctGatherEnergy](docs/V0042AcctGatherEnergy.md)
 - [V0042Assoc](docs/V0042Assoc.md)
 - [V0042AssocDefault](docs/V0042AssocDefault.md)
 - [V0042AssocMax](docs/V0042AssocMax.md)
 - [V0042AssocMaxJobs](docs/V0042AssocMaxJobs.md)
 - [V0042AssocMaxJobsPer](docs/V0042AssocMaxJobsPer.md)
 - [V0042AssocMaxPer](docs/V0042AssocMaxPer.md)
 - [V0042AssocMaxPerAccount](docs/V0042AssocMaxPerAccount.md)
 - [V0042AssocMaxTres](docs/V0042AssocMaxTres.md)
 - [V0042AssocMaxTresGroup](docs/V0042AssocMaxTresGroup.md)
 - [V0042AssocMaxTresMinutes](docs/V0042AssocMaxTresMinutes.md)
 - [V0042AssocMaxTresPer](docs/V0042AssocMaxTresPer.md)
 - [V0042AssocMin](docs/V0042AssocMin.md)
 - [V0042AssocRecSet](docs/V0042AssocRecSet.md)
 - [V0042AssocSharesObjWrap](docs/V0042AssocSharesObjWrap.md)
 - [V0042AssocSharesObjWrapFairshare](docs/V0042AssocSharesObjWrapFairshare.md)
 - [V0042AssocSharesObjWrapTres](docs/V0042AssocSharesObjWrapTres.md)
 - [V0042AssocShort](docs/V0042AssocShort.md)
 - [V0042BfExitFields](docs/V0042BfExitFields.md)
 - [V0042ClusterRec](docs/V0042ClusterRec.md)
 - [V0042ClusterRecAssociations](docs/V0042ClusterRecAssociations.md)
 - [V0042ClusterRecController](docs/V0042ClusterRecController.md)
 - [V0042ControllerPing](docs/V0042ControllerPing.md)
 - [V0042Coord](docs/V0042Coord.md)
 - [V0042CronEntry](docs/V0042CronEntry.md)
 - [V0042CronEntryLine](docs/V0042CronEntryLine.md)
 - [V0042Float64NoValStruct](docs/V0042Float64NoValStruct.md)
 - [V0042Instance](docs/V0042Instance.md)
 - [V0042InstanceTime](docs/V0042InstanceTime.md)
 - [V0042Job](docs/V0042Job.md)
 - [V0042JobAllocReq](docs/V0042JobAllocReq.md)
 - [V0042JobArray](docs/V0042JobArray.md)
 - [V0042JobArrayLimits](docs/V0042JobArrayLimits.md)
 - [V0042JobArrayLimitsMax](docs/V0042JobArrayLimitsMax.md)
 - [V0042JobArrayLimitsMaxRunning](docs/V0042JobArrayLimitsMaxRunning.md)
 - [V0042JobArrayResponseMsgEntry](docs/V0042JobArrayResponseMsgEntry.md)
 - [V0042JobComment](docs/V0042JobComment.md)
 - [V0042JobDescMsg](docs/V0042JobDescMsg.md)
 - [V0042JobDescMsgRlimits](docs/V0042JobDescMsgRlimits.md)
 - [V0042JobHet](docs/V0042JobHet.md)
 - [V0042JobInfo](docs/V0042JobInfo.md)
 - [V0042JobInfoPower](docs/V0042JobInfoPower.md)
 - [V0042JobMcs](docs/V0042JobMcs.md)
 - [V0042JobRequired](docs/V0042JobRequired.md)
 - [V0042JobRes](docs/V0042JobRes.md)
 - [V0042JobResCore](docs/V0042JobResCore.md)
 - [V0042JobResNode](docs/V0042JobResNode.md)
 - [V0042JobResNodeCpus](docs/V0042JobResNodeCpus.md)
 - [V0042JobResNodeMemory](docs/V0042JobResNodeMemory.md)
 - [V0042JobResNodes](docs/V0042JobResNodes.md)
 - [V0042JobResSocket](docs/V0042JobResSocket.md)
 - [V0042JobReservation](docs/V0042JobReservation.md)
 - [V0042JobState](docs/V0042JobState.md)
 - [V0042JobSubmitReq](docs/V0042JobSubmitReq.md)
 - [V0042JobTime](docs/V0042JobTime.md)
 - [V0042JobTimeSystem](docs/V0042JobTimeSystem.md)
 - [V0042JobTimeTotal](docs/V0042JobTimeTotal.md)
 - [V0042JobTimeUser](docs/V0042JobTimeUser.md)
 - [V0042JobTres](docs/V0042JobTres.md)
 - [V0042KillJobsMsg](docs/V0042KillJobsMsg.md)
 - [V0042KillJobsRespJob](docs/V0042KillJobsRespJob.md)
 - [V0042KillJobsRespJobError](docs/V0042KillJobsRespJobError.md)
 - [V0042KillJobsRespJobFederation](docs/V0042KillJobsRespJobFederation.md)
 - [V0042License](docs/V0042License.md)
 - [V0042Node](docs/V0042Node.md)
 - [V0042OpenapiAccountsAddCondResp](docs/V0042OpenapiAccountsAddCondResp.md)
 - [V0042OpenapiAccountsAddCondRespStr](docs/V0042OpenapiAccountsAddCondRespStr.md)
 - [V0042OpenapiAccountsRemovedResp](docs/V0042OpenapiAccountsRemovedResp.md)
 - [V0042OpenapiAccountsResp](docs/V0042OpenapiAccountsResp.md)
 - [V0042OpenapiAssocsRemovedResp](docs/V0042OpenapiAssocsRemovedResp.md)
 - [V0042OpenapiAssocsResp](docs/V0042OpenapiAssocsResp.md)
 - [V0042OpenapiClustersRemovedResp](docs/V0042OpenapiClustersRemovedResp.md)
 - [V0042OpenapiClustersResp](docs/V0042OpenapiClustersResp.md)
 - [V0042OpenapiDiagResp](docs/V0042OpenapiDiagResp.md)
 - [V0042OpenapiError](docs/V0042OpenapiError.md)
 - [V0042OpenapiInstancesResp](docs/V0042OpenapiInstancesResp.md)
 - [V0042OpenapiJobAllocResp](docs/V0042OpenapiJobAllocResp.md)
 - [V0042OpenapiJobInfoResp](docs/V0042OpenapiJobInfoResp.md)
 - [V0042OpenapiJobPostResponse](docs/V0042OpenapiJobPostResponse.md)
 - [V0042OpenapiJobSubmitResponse](docs/V0042OpenapiJobSubmitResponse.md)
 - [V0042OpenapiKillJobResp](docs/V0042OpenapiKillJobResp.md)
 - [V0042OpenapiKillJobsResp](docs/V0042OpenapiKillJobsResp.md)
 - [V0042OpenapiLicensesResp](docs/V0042OpenapiLicensesResp.md)
 - [V0042OpenapiMeta](docs/V0042OpenapiMeta.md)
 - [V0042OpenapiMetaClient](docs/V0042OpenapiMetaClient.md)
 - [V0042OpenapiMetaPlugin](docs/V0042OpenapiMetaPlugin.md)
 - [V0042OpenapiMetaSlurm](docs/V0042OpenapiMetaSlurm.md)
 - [V0042OpenapiMetaSlurmVersion](docs/V0042OpenapiMetaSlurmVersion.md)
 - [V0042OpenapiNodesResp](docs/V0042OpenapiNodesResp.md)
 - [V0042OpenapiPartitionResp](docs/V0042OpenapiPartitionResp.md)
 - [V0042OpenapiPingArrayResp](docs/V0042OpenapiPingArrayResp.md)
 - [V0042OpenapiReservationResp](docs/V0042OpenapiReservationResp.md)
 - [V0042OpenapiResp](docs/V0042OpenapiResp.md)
 - [V0042OpenapiSharesResp](docs/V0042OpenapiSharesResp.md)
 - [V0042OpenapiSlurmdbdConfigResp](docs/V0042OpenapiSlurmdbdConfigResp.md)
 - [V0042OpenapiSlurmdbdJobsResp](docs/V0042OpenapiSlurmdbdJobsResp.md)
 - [V0042OpenapiSlurmdbdPingResp](docs/V0042OpenapiSlurmdbdPingResp.md)
 - [V0042OpenapiSlurmdbdQosRemovedResp](docs/V0042OpenapiSlurmdbdQosRemovedResp.md)
 - [V0042OpenapiSlurmdbdQosResp](docs/V0042OpenapiSlurmdbdQosResp.md)
 - [V0042OpenapiSlurmdbdStatsResp](docs/V0042OpenapiSlurmdbdStatsResp.md)
 - [V0042OpenapiTresResp](docs/V0042OpenapiTresResp.md)
 - [V0042OpenapiUsersAddCondResp](docs/V0042OpenapiUsersAddCondResp.md)
 - [V0042OpenapiUsersAddCondRespStr](docs/V0042OpenapiUsersAddCondRespStr.md)
 - [V0042OpenapiUsersResp](docs/V0042OpenapiUsersResp.md)
 - [V0042OpenapiWarning](docs/V0042OpenapiWarning.md)
 - [V0042OpenapiWckeyRemovedResp](docs/V0042OpenapiWckeyRemovedResp.md)
 - [V0042OpenapiWckeyResp](docs/V0042OpenapiWckeyResp.md)
 - [V0042PartPrio](docs/V0042PartPrio.md)
 - [V0042PartitionInfo](docs/V0042PartitionInfo.md)
 - [V0042PartitionInfoAccounts](docs/V0042PartitionInfoAccounts.md)
 - [V0042PartitionInfoCpus](docs/V0042PartitionInfoCpus.md)
 - [V0042PartitionInfoDefaults](docs/V0042PartitionInfoDefaults.md)
 - [V0042PartitionInfoGroups](docs/V0042PartitionInfoGroups.md)
 - [V0042PartitionInfoMaximums](docs/V0042PartitionInfoMaximums.md)
 - [V0042PartitionInfoMaximumsOversubscribe](docs/V0042PartitionInfoMaximumsOversubscribe.md)
 - [V0042PartitionInfoMinimums](docs/V0042PartitionInfoMinimums.md)
 - [V0042PartitionInfoNodes](docs/V0042PartitionInfoNodes.md)
 - [V0042PartitionInfoPartition](docs/V0042PartitionInfoPartition.md)
 - [V0042PartitionInfoPriority](docs/V0042PartitionInfoPriority.md)
 - [V0042PartitionInfoQos](docs/V0042PartitionInfoQos.md)
 - [V0042PartitionInfoTimeouts](docs/V0042PartitionInfoTimeouts.md)
 - [V0042PartitionInfoTres](docs/V0042PartitionInfoTres.md)
 - [V0042ProcessExitCodeVerbose](docs/V0042ProcessExitCodeVerbose.md)
 - [V0042ProcessExitCodeVerboseSignal](docs/V0042ProcessExitCodeVerboseSignal.md)
 - [V0042Qos](docs/V0042Qos.md)
 - [V0042QosLimits](docs/V0042QosLimits.md)
 - [V0042QosLimitsMax](docs/V0042QosLimitsMax.md)
 - [V0042QosLimitsMaxActiveJobs](docs/V0042QosLimitsMaxActiveJobs.md)
 - [V0042QosLimitsMaxJobs](docs/V0042QosLimitsMaxJobs.md)
 - [V0042QosLimitsMaxJobsActiveJobs](docs/V0042QosLimitsMaxJobsActiveJobs.md)
 - [V0042QosLimitsMaxJobsActiveJobsPer](docs/V0042QosLimitsMaxJobsActiveJobsPer.md)
 - [V0042QosLimitsMaxTres](docs/V0042QosLimitsMaxTres.md)
 - [V0042QosLimitsMaxTresMinutes](docs/V0042QosLimitsMaxTresMinutes.md)
 - [V0042QosLimitsMaxTresMinutesPer](docs/V0042QosLimitsMaxTresMinutesPer.md)
 - [V0042QosLimitsMaxTresPer](docs/V0042QosLimitsMaxTresPer.md)
 - [V0042QosLimitsMaxWallClock](docs/V0042QosLimitsMaxWallClock.md)
 - [V0042QosLimitsMaxWallClockPer](docs/V0042QosLimitsMaxWallClockPer.md)
 - [V0042QosLimitsMin](docs/V0042QosLimitsMin.md)
 - [V0042QosLimitsMinTres](docs/V0042QosLimitsMinTres.md)
 - [V0042QosLimitsMinTresPer](docs/V0042QosLimitsMinTresPer.md)
 - [V0042QosPreempt](docs/V0042QosPreempt.md)
 - [V0042ReservationCoreSpec](docs/V0042ReservationCoreSpec.md)
 - [V0042ReservationInfo](docs/V0042ReservationInfo.md)
 - [V0042ReservationInfoPurgeCompleted](docs/V0042ReservationInfoPurgeCompleted.md)
 - [V0042RollupStats](docs/V0042RollupStats.md)
 - [V0042RollupStatsDaily](docs/V0042RollupStatsDaily.md)
 - [V0042RollupStatsDailyDuration](docs/V0042RollupStatsDailyDuration.md)
 - [V0042RollupStatsHourly](docs/V0042RollupStatsHourly.md)
 - [V0042RollupStatsHourlyDuration](docs/V0042RollupStatsHourlyDuration.md)
 - [V0042RollupStatsMonthly](docs/V0042RollupStatsMonthly.md)
 - [V0042RollupStatsMonthlyDuration](docs/V0042RollupStatsMonthlyDuration.md)
 - [V0042ScheduleExitFields](docs/V0042ScheduleExitFields.md)
 - [V0042SharesFloat128Tres](docs/V0042SharesFloat128Tres.md)
 - [V0042SharesRespMsg](docs/V0042SharesRespMsg.md)
 - [V0042SharesUint64Tres](docs/V0042SharesUint64Tres.md)
 - [V0042SlurmdbdPing](docs/V0042SlurmdbdPing.md)
 - [V0042StatsMsg](docs/V0042StatsMsg.md)
 - [V0042StatsMsgRpcDump](docs/V0042StatsMsgRpcDump.md)
 - [V0042StatsMsgRpcQueue](docs/V0042StatsMsgRpcQueue.md)
 - [V0042StatsMsgRpcType](docs/V0042StatsMsgRpcType.md)
 - [V0042StatsMsgRpcUser](docs/V0042StatsMsgRpcUser.md)
 - [V0042StatsRec](docs/V0042StatsRec.md)
 - [V0042StatsRpc](docs/V0042StatsRpc.md)
 - [V0042StatsRpcTime](docs/V0042StatsRpcTime.md)
 - [V0042StatsUser](docs/V0042StatsUser.md)
 - [V0042Step](docs/V0042Step.md)
 - [V0042StepCPU](docs/V0042StepCPU.md)
 - [V0042StepCPURequestedFrequency](docs/V0042StepCPURequestedFrequency.md)
 - [V0042StepNodes](docs/V0042StepNodes.md)
 - [V0042StepStatistics](docs/V0042StepStatistics.md)
 - [V0042StepStatisticsCPU](docs/V0042StepStatisticsCPU.md)
 - [V0042StepStatisticsEnergy](docs/V0042StepStatisticsEnergy.md)
 - [V0042StepStep](docs/V0042StepStep.md)
 - [V0042StepTask](docs/V0042StepTask.md)
 - [V0042StepTasks](docs/V0042StepTasks.md)
 - [V0042StepTime](docs/V0042StepTime.md)
 - [V0042StepTimeSystem](docs/V0042StepTimeSystem.md)
 - [V0042StepTimeTotal](docs/V0042StepTimeTotal.md)
 - [V0042StepTimeUser](docs/V0042StepTimeUser.md)
 - [V0042StepTres](docs/V0042StepTres.md)
 - [V0042StepTresConsumed](docs/V0042StepTresConsumed.md)
 - [V0042StepTresRequested](docs/V0042StepTresRequested.md)
 - [V0042Tres](docs/V0042Tres.md)
 - [V0042Uint16NoValStruct](docs/V0042Uint16NoValStruct.md)
 - [V0042Uint32NoValStruct](docs/V0042Uint32NoValStruct.md)
 - [V0042Uint64NoValStruct](docs/V0042Uint64NoValStruct.md)
 - [V0042UpdateNodeMsg](docs/V0042UpdateNodeMsg.md)
 - [V0042User](docs/V0042User.md)
 - [V0042UserDefault](docs/V0042UserDefault.md)
 - [V0042UserShort](docs/V0042UserShort.md)
 - [V0042UsersAddCond](docs/V0042UsersAddCond.md)
 - [V0042Wckey](docs/V0042Wckey.md)
 - [V0042WckeyTagStruct](docs/V0042WckeyTagStruct.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="user"></a>
### user

- **Type**: API key
- **API key parameter name**: X-SLURM-USER-NAME
- **Location**: HTTP header

<a id="token"></a>
### token

- **Type**: API key
- **API key parameter name**: X-SLURM-USER-TOKEN
- **Location**: HTTP header

<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)


## Author

sales@schedmd.com


